package com.persagy.apm.report.config.statisticsitems.model;

import com.persagy.apm.report.config.statisticsitems.model.dto.AddStatisticItemsDTO;
import com.persagy.apm.report.config.statisticsitems.model.dto.UpdateStatisticItemsDTO;
import com.persagy.apm.report.config.statisticsitems.model.vo.ResponseStatisticItemsItemVO;
import com.persagy.apm.report.config.statisticsitems.model.vo.ResponseStatisticItemsListItemVO;
import org.mapstruct.Mapper;
import org.mapstruct.MappingTarget;
import org.mapstruct.NullValueCheckStrategy;
import org.mapstruct.NullValueMappingStrategy;
import org.mapstruct.factory.Mappers;

import java.util.List;

/**
 * 统计条目(StatisticItems) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-05-20 19:21:12 2021-05-20 19:21:12
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertStatisticItemsTool {

    ConvertStatisticItemsTool INSTANCE = Mappers.getMapper(ConvertStatisticItemsTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param statisticItems do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-05-20 19:21:12
     */
    ResponseStatisticItemsItemVO convert2ResponseItemDTO(StatisticItems statisticItems);

    /**
     * do转换为ResponseListItemVO
     *
     * @param statisticItems do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-05-20 19:21:12
     */
    ResponseStatisticItemsListItemVO convert2ResponseListItemDTO(StatisticItems statisticItems);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param statisticItemsList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-05-20 19:21:12
     */
    List<ResponseStatisticItemsListItemVO> convert2List(List<StatisticItems> statisticItemsList);

    /**
     * addDTO转换为do
     *
     * @param addStatisticItemsDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-05-20 19:21:12
     */
    StatisticItems convertAddDto2Entity(AddStatisticItemsDTO addStatisticItemsDTO);

    /**
     * updateDTO转换为实体
     *
     * @param statisticItems          更新前的do对象
     * @param updateStatisticItemsDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-05-20 19:21:12
     */
    StatisticItems convertUpdateDto2Entity(@MappingTarget StatisticItems statisticItems, UpdateStatisticItemsDTO updateStatisticItemsDTO);
}

